/**
 * Author: Andrei Heidelbacher
 * Task: Tournament
 * Time complexity: O(N^7) (overestimated)
 * Space complexity: O(N^2)
 * Expected score: 100 points
 */

#include <fstream>
#include <algorithm>
#include <vector>
#include <queue>

using namespace std;

const char IN_FILE[] = "tournament.in";
const char OUT_FILE[] = "tournament.out";

class FlowNetwork {
 public:
  static const int NIL = -1;
  static const int INF = 0x3f3f3f3f;

  FlowNetwork(const int _V = 0):
   V(_V),
   E(0),
   graph(vector<vector<int>>(_V, vector<int>())),
   edges(vector<Edge>()) {}

  void addEdge(const int from, const int to, const int capacity) {
    edges.push_back(Edge(from, to, capacity));
    graph[from].push_back(E);
    ++E;
  }

  int getMaximumFlow(const int source, const int sink) {
    initializeFlowNetwork();
    int maxFlow = 0;
    for (vector<int> father = bfs(source, sink); father[sink] != NIL; father = bfs(source, sink)) {
      for (const int &e: graph[sink]) {
        if (edges[nonEdge(e)].isSaturated() || father[edges[e].v] == NIL)
          continue;
        father[sink] = nonEdge(e);
        int flow = INF;
        for (int x = sink; x != source; x = edges[father[x]].u)
          flow = min(flow, edges[father[x]].capacity - edges[father[x]].flow);
        for (int x = sink; x != source; x = edges[father[x]].u) {
          edges[father[x]].flow += flow;
          edges[nonEdge(father[x])].flow -= flow;
        }
        maxFlow += flow;
      }
    }
    clearResidualNetwork();
    return maxFlow;
  }

 private:
  class Edge {
   public:
    int u, v, capacity, flow;

    Edge() {}

    Edge(const int _u, const int _v, const int _capacity):
     u(_u),
     v(_v),
     capacity(_capacity),
     flow(0) {}

    bool isSaturated() const {
      return capacity == flow;
    }
  };

  int V, E;
  vector<vector<int>> graph;
  vector<Edge> edges;

  int nonEdge(const int edgeIndex) const {
    if (edgeIndex < E)
      return edgeIndex + E;
    else
      return edgeIndex - E;
  }

  vector<int> bfs(const int start, const int end) const {
    vector<int> father = vector<int>(V, NIL);
    father[start] = start;
    queue<int> q;
    for (q.push(start); !q.empty(); q.pop()) {
      int x = q.front();
      if (x == end)
        continue;
      for (const int &e: graph[x]) {
        if (!edges[e].isSaturated() && father[edges[e].v] == NIL) {
          father[edges[e].v] = e;
          q.push(edges[e].v);
        }
      }
    }
    return father;
  }

  void initializeFlowNetwork() {
    edges.resize(2 * E);
    for (int e = 0; e < E; ++e) {
      edges[e].flow = 0;
      edges[nonEdge(e)] = Edge(edges[e].v, edges[e].u, 0);
      graph[edges[e].v].push_back(nonEdge(e));
    }
  }

  void clearResidualNetwork() {
    edges.resize(E);
    for (int e = E - 1; e >= 0; --e)
      graph[edges[e].v].pop_back();
  }
};

const int FlowNetwork::NIL;

int main() {
  ifstream in(IN_FILE);
  int n;
  in >> n;
  vector<int> wins = vector<int>(n);
  vector<vector<int>> remaining = vector<vector<int>>(n, vector<int>(n));
  for (int x = 0; x < n; ++x)
    in >> wins[x];
  for (int x = 0; x < n; ++x)
    for (int y = 0; y < n; ++y)
      in >> remaining[x][y];
  in.close();

  vector<int> champions;
  for (int champion = 0; champion < n; ++champion) {
    int championWins = wins[champion];
    for (int x = 0; x < n; ++x)
      championWins += remaining[champion][x];
    bool isChampion = true;
    for (int x = 0; x < n; ++x)
      if (x != champion && wins[x] > championWins)
        isChampion = false;
    if (isChampion) {
      FlowNetwork network = FlowNetwork(n * n + n + 2);
      const int source = n * n + n;
      const int sink = n * n + n + 1;
      int requiredFlow = 0;
      for (int x = 0; x < n; ++x) {
        if (x == champion)
          continue;
        network.addEdge(n * n + x, sink, championWins - wins[x]);
        for (int y = x + 1; y < n; ++y) {
          if (y == champion)
            continue;
          network.addEdge(source, x * n + y, remaining[x][y]);
          requiredFlow += remaining[x][y];
          network.addEdge(x * n + y, n * n + x, FlowNetwork::INF);
          network.addEdge(x * n + y, n * n + y, FlowNetwork::INF);
        }
      }
      if (network.getMaximumFlow(source, sink) < requiredFlow)
        isChampion = false;
    }
    if (isChampion)
      champions.push_back(champion);
  }

  ofstream out(OUT_FILE);
  out << int(champions.size()) << "\n";
  for (int i = 0; i < int(champions.size()); ++i)
    out << champions[i] << " ";
  out << "\n";
  out.close();
  return 0;
}
