/**
 * Author: Andrei Heidelbacher
 * Task: Asalt
 * Time complexity: O(N)
 * Space complexity: O(N)
 * Expected score: 100 points
 */

#include <cmath>

#include <algorithm>
#include <vector>
#include <map>

#include "header.h"

using namespace std;

const double EPS = 1e-7;

class Point {
 public:
  double x, y;

  Point() {}

  Point(const double _x, const double _y):
   x(_x),
   y(_y) {}

  bool operator<(const Point &other) const {
    if (abs(other.x - x) > EPS)
      return x < other.x;
    if (abs(other.y - y) > EPS)
      return y < other.y;
    return false;
  }

  bool operator==(const Point &other) const {
    return (abs(other.x - x) < EPS && abs(other.y - y) < EPS);
  }
};

class Circle {
 public:
  double x, y, r;

  Circle() {}

  Circle(const double _x, const double _y, const double _r):
   x(_x),
   y(_y),
   r(_r) {}

  Circle(const Point &_c, const double _r):
   x(_c.x),
   y(_c.y),
   r(_r) {}

  double value(const Point &p) const {
    return (p.x - x) * (p.x - x) + (p.y - y) * (p.y - y) - r * r;
  }

  bool operator==(const Circle &other) const {
    return (abs(x - other.x) < EPS && abs(y - other.y) < EPS && abs(r - other.r) < EPS);
  }
};

map<pair<int, int>, double> distances;

inline double distance(const Point &a, const Point &b) {
  return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

vector<Point> intersectCircles(const Circle &c0, const Circle &c1) {
  vector<Point> solutions;
  const double d = sqrt((c0.x - c1.x) * (c0.x - c1.x) + (c0.y - c1.y) * (c0.y - c1.y));
  if (abs(d) < EPS && abs(c0.r - c1.r) < EPS) {
    solutions.push_back(Point(c0.x + c0.r, c0.y));
    solutions.push_back(Point(c0.x + c0.r, c0.y));
  }
  if (d + EPS < c0.r - c1.r || c0.r + c1.r < d - EPS || abs(d) < EPS)
    return solutions;
  const double a = (c0.r * c0.r - c1.r * c1.r + d * d) / (2 * d);
  const double h = sqrt(abs(c0.r * c0.r - a * a));
  const Point p = Point(c0.x + a * (c1.x - c0.x) / d, c0.y + a * (c1.y - c0.y) / d);
  solutions.push_back(Point(p.x + h * (c1.y - c0.y) / d, p.y - h * (c1.x - c0.x) / d));
  solutions.push_back(Point(p.x - h * (c1.y - c0.y) / d, p.y + h * (c1.x - c0.x) / d));
  if (distance(solutions[0], solutions[1]) < EPS)
    solutions.pop_back();
  return solutions;
}

inline double getDistance(const int i, const int j) {
  if (j < i)
    return getDistance(j, i);
  if (i == j)
    return 0.0;
  if (distances.find(make_pair(i, j)) != distances.end())
    return distances[make_pair(i, j)];
  return distances[make_pair(i, j)] = query(i, j);
}

void recover(int N) {
  const int n = N;
  vector<Point> points = vector<Point>(n);
  const int a = 0;
  points[a] = Point(0.0, 0.0);
  int b = 1;
  points[b] = Point(0.0, getDistance(a, b));
  while (b < n && abs(points[b].y) < EPS) {
    ++b;
    points[b] = Point(0.0, getDistance(a, b));
  }
  int c = b + 1;
  while (c < n) {
    vector<Point> solutions = intersectCircles(
        Circle(points[a], getDistance(a, c)),
        Circle(points[b], getDistance(b, c))
    );
    points[c] = solutions[0];
    if (int(solutions.size()) > 1)
      break;
    else
      ++c;
  }
  for (int i = c + 1; i < n; ++i) {
    vector<Point> solutions = intersectCircles(
        Circle(points[a], getDistance(a, i)),
        Circle(points[b], getDistance(b, i))
    );
    if (int(solutions.size()) > 1) {
      const double d0 = abs(getDistance(c, i) - distance(solutions[0], points[c]));
      const double d1 = abs(getDistance(c, i) - distance(solutions[1], points[c]));
      points[i] = d0 < d1 ? solutions[0] : solutions[1];
    } else {
      points[i] = solutions[0];
    }
  }
  double *x = new double[n];
  double *y = new double[n];
  for (int i = 0; i < n; ++i) {
    x[i] = points[i].x;
    y[i] = points[i].y;
  }
  sendRecovered(x, y);
}
