#include <cstdio>
#include <cmath>
#include <cstdlib>
#include <ctime>
#include <cassert>

#include <algorithm>
#include <vector>

#define x first
#define y second

using namespace std;

typedef pair<double, double> Point;

const char IN_FILE[] = "asalt.in";
const int MIN_C = -1000000000;
const int MAX_C = 1000000000;
const double PI = acos(-1.0);
const double EPS = 1e-6;

inline int Abs(const int value) {
    if (value < 0)
        return -value;
    return value;
}

inline int Random() {
    return rand() | (rand() << 16);
}

inline int Random(const int lower, const int upper) {
    return lower + Abs(Random()) % (upper - lower + 1);
}

inline Point GeneratePoint(const int lower, const int upper) {
    return Point(Random(lower, upper) * 1e-6, Random(lower, upper) * 1e-6);
}

inline double Distance(const Point &A, const Point &B) {
    return sqrt((A.x - B.x) * (A.x - B.x) + (A.y - B.y) * (A.y - B.y));
}

vector<Point> GenerateRandomTest(const int n) {
    vector<Point> points = vector<Point>(n);
    for (int i = 0; i < n; ++i)
        points[i] = GeneratePoint(MIN_C, MAX_C);
    return points;
}

vector<Point> GenerateCollinearTest(const int n) {
    vector<Point> points = vector<Point>(n);
    points[0] = GeneratePoint(MIN_C, MAX_C);
    int axis = Random(0, 1);
    for (int i = 1; i < n; ++i) {
        if (axis == 0)
            points[i] = Point(points[0].x, Random(MIN_C, MAX_C) * 1e-6);
        else
            points[i] = Point(Random(MIN_C, MAX_C) * 1e-6, points[0].y);
    }
    return points;
}

vector<Point> GenerateMixedTest(const int n) {
    vector<Point> collinear = GenerateCollinearTest(Random(1, n / 5));
    vector<Point> random = GenerateRandomTest(n - int(collinear.size()));
    vector<Point> points = collinear;
    points.insert(points.end(), random.begin(), random.end());
    random_shuffle(points.begin(), points.end());
    return points;
}

vector<Point> GenerateRegulatedPolygon(const int n) {
    double radius = 950.0;
    vector<Point> points = vector<Point>(n);
    for (int i = 0; i < n; ++i)
        points[i] = Point(radius * cos(2.0 * i * PI / (1.0 * n)), radius * sin(2.0 * i * PI / (1.0 * n)));
    random_shuffle(points.begin(), points.end());
    return points;
}

vector<Point> GenerateNonCollinear(const int n) {
    return GenerateRandomTest(n);
}

inline double Det(const Point &a, const Point &b, const Point &c) {
    return (b.x - a.x) * (c.y - a.y) - (c.x - a.x) * (b.y - a.y);
}

class Compare {
  public:
    static vector<double> alpha;

    bool operator()(const int a, const int b) const {
        return alpha[a] < alpha[b];
    }
};

vector<double> Compare::alpha = vector<double>();

vector<int> ConvexHull(const vector<Point> &points) {
    int n = int(points.size());
    int center = 0;
    for (int i = 1; i < n; ++i)
        if (points[i] < points[center])
            center = i;
    vector<double> alpha = vector<double>(n);
    for (int i = 0; i < n; ++i)
        alpha[i] = atan2(points[i].y - points[center].y, points[i].x - points[center].x);
    vector<int> index = vector<int>(n);
    for (int i = 0; i < n; ++i)
        index[i] = i;
    swap(index[0], index[center]);
    Compare::alpha = alpha;
    sort(index.begin() + 1, index.end(), Compare());
    vector<int> hull;
    hull.push_back(index[0]);
    hull.push_back(index[1]);
    for (int i = 2; i < n; ++i) {
        while (int(hull.size()) > 1 && Det(points[hull[int(hull.size()) - 2]], points[hull.back()], points[index[i]]) < -EPS)
            hull.pop_back();
        hull.push_back(index[i]);
    }
    return hull;
}

vector<Point> GenerateSpecialHalfSolution(const int n) {
    vector<Point> points = GenerateNonCollinear(n);
    vector<int> hull = ConvexHull(points);
    swap(points[0], points[hull[0]]);
    swap(points[1], points[hull[1]]);
    return points;
}

void PrintTest(const int n, const vector<Point> &points) {
    assert(freopen(IN_FILE, "w", stdout));
    printf("%d\n", n);
    for (int i = 0; i < n; ++i)
        printf("%.6lf %.6lf\n", points[i].x, points[i].y);
    fclose(stdout);
}

int main() {
    srand(time(0));
    int n = 500;
    //PrintTest(n, GenerateMixedTest(n));
    //PrintTest(n, GenerateRandomTest(n));
    //PrintTest(n, GenerateCollinearTest(n));
    PrintTest(n, GenerateRegulatedPolygon(n));
    //PrintTest(n, GenerateSpecialHalfSolution(n));
    return 0;
}
