/*
 * Copyright 2016 Andrei Heidelbacher <andrei.heidelbacher@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.math.MathContext;
import java.util.Scanner;

public class Expected {
  public static class Rational {
    private final BigInteger num;
    private final BigInteger denom;

    public Rational(final BigInteger num, final BigInteger denom) {
      final BigInteger gcd = num.gcd(denom);
      this.num = num.divide(gcd);
      this.denom = denom.divide(gcd);
    }

    public Rational(final long num, final long denom) {
      this(BigInteger.valueOf(num), BigInteger.valueOf(denom));
    }

    public Rational(final long value) {
      this(value, 1);
    }

    public Rational add(final Rational other) {
      return new Rational(
          num.multiply(other.denom).add(other.num.multiply(denom)),
          denom.multiply(other.denom)
      );
    }

    public Rational subtract(final Rational other) {
      return new Rational(
          num.multiply(other.denom).subtract(other.num.multiply(denom)),
          denom.multiply(other.denom)
      );
    }

    public Rational multiply(final Rational other) {
      return new Rational(num.multiply(other.num), denom.multiply(other.denom));
    }

    public Rational multiply(final long other) {
      return new Rational(num.multiply(BigInteger.valueOf(other)), denom);
    }

    public Rational divide(final Rational other) {
      return new Rational(num.multiply(other.denom), denom.multiply(other.num));
    }

    public Rational divide(final long other) {
      return new Rational(num, denom.multiply(BigInteger.valueOf(other)));
    }

    public BigDecimal toRealValue() {
      return new BigDecimal(num).divide(new BigDecimal(denom), MathContext.DECIMAL128);
    }
  }

  public static class Input {
    public final int n;
    public final int k;
    public final long smallSize;
    public final long bigSize;
    public final int smallCount;
    public final int bigCount;
    private final int[][] count;

    public Input(
        final int n,
        final int k,
        final long smallSize,
        final long bigSize,
        final int[] colors,
        final int[] sizes
    ) {
      assert n > 0;
      assert 0 < k && k <= n;
      assert 0 < smallSize && smallSize <= bigSize;
      assert colors != null && colors.length == n;
      for (final int color : colors) {
        assert 0 <= color && color < n;
      }
      assert sizes != null && sizes.length == n;
      for (final int size : sizes) {
        assert size == 0 || size == 1;
      }
      this.n = n;
      this.k = k;
      this.smallSize = smallSize;
      this.bigSize = bigSize;
      this.count = new int[n][2];
      for (int i = 0; i < n; ++i) {
        ++this.count[colors[i]][sizes[i]];
      }
      int small = 0;
      int big = 0;
      for (final int size : sizes) {
        if (size == 0) {
          ++small;
        } else {
          ++big;
        }
      }
      this.smallCount = small;
      this.bigCount = big;
    }

    public int getCount(final int color, final int sizeType) {
      return count[color][sizeType];
    }

    public static Input parse(final Scanner scanner) throws IOException {
      final int n = scanner.nextInt();
      final int k = scanner.nextInt();
      final long smallSize = scanner.nextLong();
      final long bigSize = scanner.nextLong();
      final int[] colors = new int[n];
      final int[] sizes = new int[n];
      for (int i = 0; i < n; ++i) {
        colors[i] = scanner.nextInt() - 1;
        sizes[i] = scanner.nextInt();
      }
      return new Input(n, k, smallSize, bigSize, colors, sizes);
    }
  }

  public static class Output {
    public final Rational answer;

    public Output(final Rational answer) {
      this.answer = answer;
    }
  }

  private static Rational[][] computeChooseProbability(final Input input) {
    final long smallSize = input.smallSize;
    final long bigSize = input.bigSize;
    final int smallCount = input.smallCount;
    final int bigCount = input.bigCount;
    Rational[][] choose = new Rational[smallCount + 1][bigCount + 1];
    for (int i = 0; i <= smallCount; ++i) {
      for (int j = 0; j <= bigCount; ++j) {
        if (i == 0 && j == 0) {
          choose[i][j] = new Rational(1);
        } else {
          choose[i][j] = new Rational(0);
          if (i > 0) {
            choose[i][j] = choose[i][j].add(
                choose[i - 1][j]
                    .multiply(smallSize * (smallCount - i + 1))
                    .divide(smallSize * (smallCount - i + 1) + bigSize * (bigCount - j))
            );
          }
          if (j > 0) {
            choose[i][j] = choose[i][j].add(
                choose[i][j - 1]
                    .multiply(bigSize * (bigCount - j + 1))
                    .divide(smallSize * (smallCount - i) + bigSize * (bigCount - j + 1))
            );
          }
        }
      }
    }
    return choose;
  }

  private static Rational[][] computeTotalWays(final int smallCount, final int bigCount) {
    final Rational[] factorials = new Rational[Math.max(smallCount, bigCount) + 1];
    factorials[0] = new Rational(1);
    for (int i = 1; i <= Math.max(smallCount, bigCount); ++i)
      factorials[i] = factorials[i - 1].multiply(i);
    final Rational[][] totalWays = new Rational[smallCount + 1][bigCount + 1];
    for (int i = 0; i <= smallCount; ++i) {
      for (int j = 0; j <= bigCount; ++j) {
        totalWays[i][j] = factorials[smallCount]
            .divide(factorials[smallCount - i])
            .multiply(factorials[bigCount])
            .divide(factorials[bigCount - j]);
      }
    }
    return totalWays;
  }

  private static Rational[][][] computeDp(final Input input) {
    final int n = input.n;
    final int smallCount = input.smallCount;
    final int bigCount = input.bigCount;
    final Rational[][] totalWays = computeTotalWays(smallCount, bigCount);
    final Rational[][][] dp = new Rational[n + 1][smallCount + 1][bigCount + 1];
    for (int i = 0; i <= n; ++i)
      for (int j = 0; j <= smallCount; ++j)
        for (int k = 0; k <= bigCount; ++k)
          dp[i][j][k] = new Rational(0);
    dp[0][0][0] = new Rational(1).divide(totalWays[0][0]);
    for (int i = 1; i <= n; ++i) {
      for (int small = 0; small <= smallCount && small <= i; ++small) {
        for (int big = 0; big <= bigCount && small + big <= i; ++big) {
          dp[i][small][big] = dp[i - 1][small][big];
          if (small > 0) {
            dp[i][small][big] = dp[i][small][big].add(
                dp[i - 1][small - 1][big]
                    .divide(totalWays[small][big])
                    .multiply(totalWays[small - 1][big])
                    .multiply((long) small * input.getCount(i - 1, 0))
            );
          }
          if (big > 0) {
            dp[i][small][big] = dp[i][small][big].add(
                dp[i - 1][small][big - 1]
                    .divide(totalWays[small][big])
                    .multiply(totalWays[small][big - 1])
                    .multiply((long) big * input.getCount(i - 1, 1))
            );
          }
        }
      }
    }
    return dp;
  }

  public static Output solveTestCase(final Input input) {
    final Rational[][] choose = computeChooseProbability(input);
    final Rational[][][] dp = computeDp(input);
    final int n = input.n;
    final int k = input.k;
    final int smallCount = input.smallCount;
    final int bigCount = input.bigCount;
    Rational answer = new Rational(0);
    for (int small = 0; small <= smallCount && small <= k; ++small) {
      final int big = k - small;
      if (0 <= big && big <= bigCount) {
        answer = answer.add(
            choose[small][big].multiply(new Rational(1).subtract(dp[n][small][big]))
        );
      }
    }
    return new Output(answer);
  }

  public static final String INPUT_FILE = "expected.in";

  public static final String OUTPUT_FILE = "expected.out";

  public static void main(String[] args) throws IOException {
    final Scanner scanner = new Scanner(new File(INPUT_FILE));
    final Input input = Input.parse(scanner);
    scanner.close();
    final Output output = solveTestCase(input);
    final PrintWriter writer = new PrintWriter(new File(OUTPUT_FILE));
    writer.print(output.answer.toRealValue().toPlainString());
    writer.close();
  }
}
